import ReactDOM from 'react-dom/client';

function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };
  return _extends.apply(this, arguments);
}

var Dialog = /*#__PURE__*/function () {
  function Dialog(dialogBuilder) {
    this.props = {};
    this.component = dialogBuilder.component;
    this.rootId = "dialog-imperative-root-" + Math.random() * 1000000;
  }

  var _proto = Dialog.prototype;

  _proto.createView = function createView() {
    this.viewRoot = ReactDOM.createRoot(document.createElement(this.rootId));
  };

  _proto.close = function close() {
    if (this.component && this.viewRoot) {
      this.viewRoot.render(this.component(_extends({}, this.props, {
        open: false,
        onClose: function onClose() {
          return {};
        }
      })));
    }
  };

  _proto.withProps = function withProps(props) {
    this.props = props(this);
    return this;
  };

  _proto.open = function open() {
    var _this = this;

    if (!this.viewRoot) {
      this.createView();
    }

    if (this.component && this.viewRoot) {
      this.viewRoot.render(this.component(_extends({}, this.props, {
        open: true,
        onClose: function onClose() {
          _this.close();

          if ('onClose' in _this.props) {
            _this.props.onClose();
          }
        }
      })));
    }
  };

  _proto.unmount = function unmount() {
    if (this.viewRoot) {
      this.viewRoot.unmount();
    }

    var containerNode = document.getElementById(this.rootId);

    if (containerNode) {
      containerNode.remove();
    }
  };

  return Dialog;
}();

var DialogBuilder = /*#__PURE__*/function () {
  function DialogBuilder() {}

  var _proto2 = DialogBuilder.prototype;

  _proto2.setComponent = function setComponent(component) {
    this.component = component;
    return this;
  };

  _proto2.build = function build() {
    if (!this.component) {
      throw new Error("Error React-Imperative-Dialog: 'setComponent' props needs to be passed!");
    }

    return new Dialog(this);
  };

  return DialogBuilder;
}();

export { DialogBuilder };
//# sourceMappingURL=react-imperative-modal-dialog.esm.js.map
